@@ -48,6 +48,8 @@ __all__ = (
     "BackupVaultListMemberTypeDef",
     "CalculatedLifecycleTypeDef",
     "ConditionTypeDef",
+    "ControlInputParameterTypeDef",
+    "ControlScopeTypeDef",
     "CopyActionTypeDef",
     "CopyJobTypeDef",
     "CreateBackupPlanInputRequestTypeDef",
@@ -56,30 +58,44 @@ __all__ = (
     "CreateBackupSelectionOutputTypeDef",
     "CreateBackupVaultInputRequestTypeDef",
     "CreateBackupVaultOutputTypeDef",
+    "CreateFrameworkInputRequestTypeDef",
+    "CreateFrameworkOutputTypeDef",
+    "CreateReportPlanInputRequestTypeDef",
+    "CreateReportPlanOutputTypeDef",
     "DeleteBackupPlanInputRequestTypeDef",
     "DeleteBackupPlanOutputTypeDef",
     "DeleteBackupSelectionInputRequestTypeDef",
     "DeleteBackupVaultAccessPolicyInputRequestTypeDef",
     "DeleteBackupVaultInputRequestTypeDef",
     "DeleteBackupVaultNotificationsInputRequestTypeDef",
+    "DeleteFrameworkInputRequestTypeDef",
     "DeleteRecoveryPointInputRequestTypeDef",
+    "DeleteReportPlanInputRequestTypeDef",
     "DescribeBackupJobInputRequestTypeDef",
     "DescribeBackupJobOutputTypeDef",
     "DescribeBackupVaultInputRequestTypeDef",
     "DescribeBackupVaultOutputTypeDef",
     "DescribeCopyJobInputRequestTypeDef",
     "DescribeCopyJobOutputTypeDef",
+    "DescribeFrameworkInputRequestTypeDef",
+    "DescribeFrameworkOutputTypeDef",
     "DescribeGlobalSettingsOutputTypeDef",
     "DescribeProtectedResourceInputRequestTypeDef",
     "DescribeProtectedResourceOutputTypeDef",
     "DescribeRecoveryPointInputRequestTypeDef",
     "DescribeRecoveryPointOutputTypeDef",
     "DescribeRegionSettingsOutputTypeDef",
+    "DescribeReportJobInputRequestTypeDef",
+    "DescribeReportJobOutputTypeDef",
+    "DescribeReportPlanInputRequestTypeDef",
+    "DescribeReportPlanOutputTypeDef",
     "DescribeRestoreJobInputRequestTypeDef",
     "DescribeRestoreJobOutputTypeDef",
     "DisassociateRecoveryPointInputRequestTypeDef",
     "ExportBackupPlanTemplateInputRequestTypeDef",
     "ExportBackupPlanTemplateOutputTypeDef",
+    "FrameworkControlTypeDef",
+    "FrameworkTypeDef",
     "GetBackupPlanFromJSONInputRequestTypeDef",
     "GetBackupPlanFromJSONOutputTypeDef",
     "GetBackupPlanFromTemplateInputRequestTypeDef",
@@ -110,12 +126,18 @@ __all__ = (
     "ListBackupVaultsOutputTypeDef",
     "ListCopyJobsInputRequestTypeDef",
     "ListCopyJobsOutputTypeDef",
+    "ListFrameworksInputRequestTypeDef",
+    "ListFrameworksOutputTypeDef",
     "ListProtectedResourcesInputRequestTypeDef",
     "ListProtectedResourcesOutputTypeDef",
     "ListRecoveryPointsByBackupVaultInputRequestTypeDef",
     "ListRecoveryPointsByBackupVaultOutputTypeDef",
     "ListRecoveryPointsByResourceInputRequestTypeDef",
     "ListRecoveryPointsByResourceOutputTypeDef",
+    "ListReportJobsInputRequestTypeDef",
+    "ListReportJobsOutputTypeDef",
+    "ListReportPlansInputRequestTypeDef",
+    "ListReportPlansOutputTypeDef",
     "ListRestoreJobsInputRequestTypeDef",
     "ListRestoreJobsOutputTypeDef",
     "ListTagsInputRequestTypeDef",
@@ -126,12 +148,19 @@ __all__ = (
     "RecoveryPointByBackupVaultTypeDef",
     "RecoveryPointByResourceTypeDef",
     "RecoveryPointCreatorTypeDef",
+    "ReportDeliveryChannelTypeDef",
+    "ReportDestinationTypeDef",
+    "ReportJobTypeDef",
+    "ReportPlanTypeDef",
+    "ReportSettingTypeDef",
     "ResponseMetadataTypeDef",
     "RestoreJobsListMemberTypeDef",
     "StartBackupJobInputRequestTypeDef",
     "StartBackupJobOutputTypeDef",
     "StartCopyJobInputRequestTypeDef",
     "StartCopyJobOutputTypeDef",
+    "StartReportJobInputRequestTypeDef",
+    "StartReportJobOutputTypeDef",
     "StartRestoreJobInputRequestTypeDef",
     "StartRestoreJobOutputTypeDef",
     "StopBackupJobInputRequestTypeDef",
@@ -139,10 +168,14 @@ __all__ = (
     "UntagResourceInputRequestTypeDef",
     "UpdateBackupPlanInputRequestTypeDef",
     "UpdateBackupPlanOutputTypeDef",
+    "UpdateFrameworkInputRequestTypeDef",
+    "UpdateFrameworkOutputTypeDef",
     "UpdateGlobalSettingsInputRequestTypeDef",
     "UpdateRecoveryPointLifecycleInputRequestTypeDef",
     "UpdateRecoveryPointLifecycleOutputTypeDef",
     "UpdateRegionSettingsInputRequestTypeDef",
+    "UpdateReportPlanInputRequestTypeDef",
+    "UpdateReportPlanOutputTypeDef",
 )
 
 AdvancedBackupSettingTypeDef = TypedDict(
@@ -364,6 +397,25 @@ ConditionTypeDef = TypedDict(
     },
 )
 
+ControlInputParameterTypeDef = TypedDict(
+    "ControlInputParameterTypeDef",
+    {
+        "ParameterName": str,
+        "ParameterValue": str,
+    },
+    total=False,
+)
+
+ControlScopeTypeDef = TypedDict(
+    "ControlScopeTypeDef",
+    {
+        "ComplianceResourceIds": List[str],
+        "ComplianceResourceTypes": List[str],
+        "Tags": Dict[str, str],
+    },
+    total=False,
+)
+
 _RequiredCopyActionTypeDef = TypedDict(
     "_RequiredCopyActionTypeDef",
     {
@@ -505,6 +557,73 @@ CreateBackupVaultOutputTypeDef = TypedDict(
     },
 )
 
+_RequiredCreateFrameworkInputRequestTypeDef = TypedDict(
+    "_RequiredCreateFrameworkInputRequestTypeDef",
+    {
+        "FrameworkName": str,
+        "FrameworkControls": List["FrameworkControlTypeDef"],
+    },
+)
+_OptionalCreateFrameworkInputRequestTypeDef = TypedDict(
+    "_OptionalCreateFrameworkInputRequestTypeDef",
+    {
+        "FrameworkDescription": str,
+        "IdempotencyToken": str,
+        "FrameworkTags": Dict[str, str],
+    },
+    total=False,
+)
+
+
+class CreateFrameworkInputRequestTypeDef(
+    _RequiredCreateFrameworkInputRequestTypeDef, _OptionalCreateFrameworkInputRequestTypeDef
+):
+    pass
+
+
+CreateFrameworkOutputTypeDef = TypedDict(
+    "CreateFrameworkOutputTypeDef",
+    {
+        "FrameworkName": str,
+        "FrameworkArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredCreateReportPlanInputRequestTypeDef = TypedDict(
+    "_RequiredCreateReportPlanInputRequestTypeDef",
+    {
+        "ReportPlanName": str,
+        "ReportDeliveryChannel": "ReportDeliveryChannelTypeDef",
+        "ReportSetting": "ReportSettingTypeDef",
+    },
+)
+_OptionalCreateReportPlanInputRequestTypeDef = TypedDict(
+    "_OptionalCreateReportPlanInputRequestTypeDef",
+    {
+        "ReportPlanDescription": str,
+        "ReportPlanTags": Dict[str, str],
+        "IdempotencyToken": str,
+    },
+    total=False,
+)
+
+
+class CreateReportPlanInputRequestTypeDef(
+    _RequiredCreateReportPlanInputRequestTypeDef, _OptionalCreateReportPlanInputRequestTypeDef
+):
+    pass
+
+
+CreateReportPlanOutputTypeDef = TypedDict(
+    "CreateReportPlanOutputTypeDef",
+    {
+        "ReportPlanName": str,
+        "ReportPlanArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 DeleteBackupPlanInputRequestTypeDef = TypedDict(
     "DeleteBackupPlanInputRequestTypeDef",
     {
@@ -552,6 +671,13 @@ DeleteBackupVaultNotificationsInputRequestTypeDef = TypedDict(
     },
 )
 
+DeleteFrameworkInputRequestTypeDef = TypedDict(
+    "DeleteFrameworkInputRequestTypeDef",
+    {
+        "FrameworkName": str,
+    },
+)
+
 DeleteRecoveryPointInputRequestTypeDef = TypedDict(
     "DeleteRecoveryPointInputRequestTypeDef",
     {
@@ -560,6 +686,13 @@ DeleteRecoveryPointInputRequestTypeDef = TypedDict(
     },
 )
 
+DeleteReportPlanInputRequestTypeDef = TypedDict(
+    "DeleteReportPlanInputRequestTypeDef",
+    {
+        "ReportPlanName": str,
+    },
+)
+
 DescribeBackupJobInputRequestTypeDef = TypedDict(
     "DescribeBackupJobInputRequestTypeDef",
     {
@@ -629,6 +762,28 @@ DescribeCopyJobOutputTypeDef = TypedDict(
     },
 )
 
+DescribeFrameworkInputRequestTypeDef = TypedDict(
+    "DescribeFrameworkInputRequestTypeDef",
+    {
+        "FrameworkName": str,
+    },
+)
+
+DescribeFrameworkOutputTypeDef = TypedDict(
+    "DescribeFrameworkOutputTypeDef",
+    {
+        "FrameworkName": str,
+        "FrameworkArn": str,
+        "FrameworkDescription": str,
+        "FrameworkControls": List["FrameworkControlTypeDef"],
+        "CreationTime": datetime,
+        "DeploymentStatus": str,
+        "FrameworkStatus": str,
+        "IdempotencyToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 DescribeGlobalSettingsOutputTypeDef = TypedDict(
     "DescribeGlobalSettingsOutputTypeDef",
     {
@@ -675,6 +830,7 @@ DescribeRecoveryPointOutputTypeDef = TypedDict(
         "CreatedBy": "RecoveryPointCreatorTypeDef",
         "IamRoleArn": str,
         "Status": RecoveryPointStatusType,
+        "StatusMessage": str,
         "CreationDate": datetime,
         "CompletionDate": datetime,
         "BackupSizeInBytes": int,
@@ -696,6 +852,36 @@ DescribeRegionSettingsOutputTypeDef = TypedDict(
     },
 )
 
+DescribeReportJobInputRequestTypeDef = TypedDict(
+    "DescribeReportJobInputRequestTypeDef",
+    {
+        "ReportJobId": str,
+    },
+)
+
+DescribeReportJobOutputTypeDef = TypedDict(
+    "DescribeReportJobOutputTypeDef",
+    {
+        "ReportJob": "ReportJobTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DescribeReportPlanInputRequestTypeDef = TypedDict(
+    "DescribeReportPlanInputRequestTypeDef",
+    {
+        "ReportPlanName": str,
+    },
+)
+
+DescribeReportPlanOutputTypeDef = TypedDict(
+    "DescribeReportPlanOutputTypeDef",
+    {
+        "ReportPlan": "ReportPlanTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 DescribeRestoreJobInputRequestTypeDef = TypedDict(
     "DescribeRestoreJobInputRequestTypeDef",
     {
@@ -746,6 +932,39 @@ ExportBackupPlanTemplateOutputTypeDef = TypedDict(
     },
 )
 
+_RequiredFrameworkControlTypeDef = TypedDict(
+    "_RequiredFrameworkControlTypeDef",
+    {
+        "ControlName": str,
+    },
+)
+_OptionalFrameworkControlTypeDef = TypedDict(
+    "_OptionalFrameworkControlTypeDef",
+    {
+        "ControlInputParameters": List["ControlInputParameterTypeDef"],
+        "ControlScope": "ControlScopeTypeDef",
+    },
+    total=False,
+)
+
+
+class FrameworkControlTypeDef(_RequiredFrameworkControlTypeDef, _OptionalFrameworkControlTypeDef):
+    pass
+
+
+FrameworkTypeDef = TypedDict(
+    "FrameworkTypeDef",
+    {
+        "FrameworkName": str,
+        "FrameworkArn": str,
+        "FrameworkDescription": str,
+        "NumberOfControls": int,
+        "CreationTime": datetime,
+        "DeploymentStatus": str,
+    },
+    total=False,
+)
+
 GetBackupPlanFromJSONInputRequestTypeDef = TypedDict(
     "GetBackupPlanFromJSONInputRequestTypeDef",
     {
@@ -1072,6 +1291,24 @@ ListCopyJobsOutputTypeDef = TypedDict(
     },
 )
 
+ListFrameworksInputRequestTypeDef = TypedDict(
+    "ListFrameworksInputRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+ListFrameworksOutputTypeDef = TypedDict(
+    "ListFrameworksOutputTypeDef",
+    {
+        "Frameworks": List["FrameworkTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 ListProtectedResourcesInputRequestTypeDef = TypedDict(
     "ListProtectedResourcesInputRequestTypeDef",
     {
@@ -1159,6 +1396,46 @@ ListRecoveryPointsByResourceOutputTypeDef = TypedDict(
     },
 )
 
+ListReportJobsInputRequestTypeDef = TypedDict(
+    "ListReportJobsInputRequestTypeDef",
+    {
+        "ByReportPlanName": str,
+        "ByCreationBefore": Union[datetime, str],
+        "ByCreationAfter": Union[datetime, str],
+        "ByStatus": str,
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+ListReportJobsOutputTypeDef = TypedDict(
+    "ListReportJobsOutputTypeDef",
+    {
+        "ReportJobs": List["ReportJobTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListReportPlansInputRequestTypeDef = TypedDict(
+    "ListReportPlansInputRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+ListReportPlansOutputTypeDef = TypedDict(
+    "ListReportPlansOutputTypeDef",
+    {
+        "ReportPlans": List["ReportPlanTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 ListRestoreJobsInputRequestTypeDef = TypedDict(
     "ListRestoreJobsInputRequestTypeDef",
     {
@@ -1265,6 +1542,7 @@ RecoveryPointByBackupVaultTypeDef = TypedDict(
         "CreatedBy": "RecoveryPointCreatorTypeDef",
         "IamRoleArn": str,
         "Status": RecoveryPointStatusType,
+        "StatusMessage": str,
         "CreationDate": datetime,
         "CompletionDate": datetime,
         "BackupSizeInBytes": int,
@@ -1283,6 +1561,7 @@ RecoveryPointByResourceTypeDef = TypedDict(
         "RecoveryPointArn": str,
         "CreationDate": datetime,
         "Status": RecoveryPointStatusType,
+        "StatusMessage": str,
         "EncryptionKeyArn": str,
         "BackupSizeBytes": int,
         "BackupVaultName": str,
@@ -1301,6 +1580,75 @@ RecoveryPointCreatorTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredReportDeliveryChannelTypeDef = TypedDict(
+    "_RequiredReportDeliveryChannelTypeDef",
+    {
+        "S3BucketName": str,
+    },
+)
+_OptionalReportDeliveryChannelTypeDef = TypedDict(
+    "_OptionalReportDeliveryChannelTypeDef",
+    {
+        "S3KeyPrefix": str,
+        "Formats": List[str],
+    },
+    total=False,
+)
+
+
+class ReportDeliveryChannelTypeDef(
+    _RequiredReportDeliveryChannelTypeDef, _OptionalReportDeliveryChannelTypeDef
+):
+    pass
+
+
+ReportDestinationTypeDef = TypedDict(
+    "ReportDestinationTypeDef",
+    {
+        "S3BucketName": str,
+        "S3Keys": List[str],
+    },
+    total=False,
+)
+
+ReportJobTypeDef = TypedDict(
+    "ReportJobTypeDef",
+    {
+        "ReportJobId": str,
+        "ReportPlanArn": str,
+        "ReportTemplate": str,
+        "CreationTime": datetime,
+        "CompletionTime": datetime,
+        "Status": str,
+        "StatusMessage": str,
+        "ReportDestination": "ReportDestinationTypeDef",
+    },
+    total=False,
+)
+
+ReportPlanTypeDef = TypedDict(
+    "ReportPlanTypeDef",
+    {
+        "ReportPlanArn": str,
+        "ReportPlanName": str,
+        "ReportPlanDescription": str,
+        "ReportSetting": "ReportSettingTypeDef",
+        "ReportDeliveryChannel": "ReportDeliveryChannelTypeDef",
+        "DeploymentStatus": str,
+        "CreationTime": datetime,
+        "LastAttemptedExecutionTime": datetime,
+        "LastSuccessfulExecutionTime": datetime,
+    },
+    total=False,
+)
+
+ReportSettingTypeDef = TypedDict(
+    "ReportSettingTypeDef",
+    {
+        "ReportTemplate": str,
+    },
+)
+
 ResponseMetadataTypeDef = TypedDict(
     "ResponseMetadataTypeDef",
     {
@@ -1404,6 +1752,35 @@ StartCopyJobOutputTypeDef = TypedDict(
     },
 )
 
+_RequiredStartReportJobInputRequestTypeDef = TypedDict(
+    "_RequiredStartReportJobInputRequestTypeDef",
+    {
+        "ReportPlanName": str,
+    },
+)
+_OptionalStartReportJobInputRequestTypeDef = TypedDict(
+    "_OptionalStartReportJobInputRequestTypeDef",
+    {
+        "IdempotencyToken": str,
+    },
+    total=False,
+)
+
+
+class StartReportJobInputRequestTypeDef(
+    _RequiredStartReportJobInputRequestTypeDef, _OptionalStartReportJobInputRequestTypeDef
+):
+    pass
+
+
+StartReportJobOutputTypeDef = TypedDict(
+    "StartReportJobOutputTypeDef",
+    {
+        "ReportJobId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredStartRestoreJobInputRequestTypeDef = TypedDict(
     "_RequiredStartRestoreJobInputRequestTypeDef",
     {
@@ -1479,6 +1856,39 @@ UpdateBackupPlanOutputTypeDef = TypedDict(
     },
 )
 
+_RequiredUpdateFrameworkInputRequestTypeDef = TypedDict(
+    "_RequiredUpdateFrameworkInputRequestTypeDef",
+    {
+        "FrameworkName": str,
+    },
+)
+_OptionalUpdateFrameworkInputRequestTypeDef = TypedDict(
+    "_OptionalUpdateFrameworkInputRequestTypeDef",
+    {
+        "FrameworkDescription": str,
+        "FrameworkControls": List["FrameworkControlTypeDef"],
+        "IdempotencyToken": str,
+    },
+    total=False,
+)
+
+
+class UpdateFrameworkInputRequestTypeDef(
+    _RequiredUpdateFrameworkInputRequestTypeDef, _OptionalUpdateFrameworkInputRequestTypeDef
+):
+    pass
+
+
+UpdateFrameworkOutputTypeDef = TypedDict(
+    "UpdateFrameworkOutputTypeDef",
+    {
+        "FrameworkName": str,
+        "FrameworkArn": str,
+        "CreationTime": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 UpdateGlobalSettingsInputRequestTypeDef = TypedDict(
     "UpdateGlobalSettingsInputRequestTypeDef",
     {
@@ -1528,3 +1938,37 @@ UpdateRegionSettingsInputRequestTypeDef = TypedDict(
     },
     total=False,
 )
+
+_RequiredUpdateReportPlanInputRequestTypeDef = TypedDict(
+    "_RequiredUpdateReportPlanInputRequestTypeDef",
+    {
+        "ReportPlanName": str,
+    },
+)
+_OptionalUpdateReportPlanInputRequestTypeDef = TypedDict(
+    "_OptionalUpdateReportPlanInputRequestTypeDef",
+    {
+        "ReportPlanDescription": str,
+        "ReportDeliveryChannel": "ReportDeliveryChannelTypeDef",
+        "ReportSetting": "ReportSettingTypeDef",
+        "IdempotencyToken": str,
+    },
+    total=False,
+)
+
+
+class UpdateReportPlanInputRequestTypeDef(
+    _RequiredUpdateReportPlanInputRequestTypeDef, _OptionalUpdateReportPlanInputRequestTypeDef
+):
+    pass
+
+
+UpdateReportPlanOutputTypeDef = TypedDict(
+    "UpdateReportPlanOutputTypeDef",
+    {
+        "ReportPlanName": str,
+        "ReportPlanArn": str,
+        "CreationTime": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
